# Graph 3D - Playground

## Data Graph 3D expects a data table with first three to five columns: colums `x`, `y`, `z` (optional), `value`, `filtervalue` (optional).
Csv | The csv table must contain a header line with column names. Simple example Line example Animation example Moving dots example Colored dots example Sized dots example
Json | Simple example
Javascript | The javascript source must create a global variable named `data` which contains a google visualization DataTable. Simple example Function example
Google Spreadsheet | Google Spreadsheet example (view spreadsheet)
Datasource | Example (view source code)
| ## Graph
## Options
Option | Value
--- | ---
width | for example "500px" or "100%"
height | for example "500px" or "100%"
style |
showAnimationControls |
showGrid |
showPerspective |
showShadow |
keepAspectRatio |
verticalRatio | a value between 0.1 and 1.0
animationInterval | in milliseconds
animationPreload |
animationAutoStart |
xCenter |
yCenter |
xMin |
xMax |
xStep |
yMin |
yMax |
yStep |
zMin |
zMax |
zStep |
valueMin |
valueMax |